==> nextcloud-24.0.10.tgz: nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig webbadress",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig webbadress",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig webbadress",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "Disable-user-theming should be true or false" : "Inaktivera teman för användare ska vara sant eller falskt",
    "Saved" : "Sparat",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "Dark theme with high contrast mode" : "Mörkt tema med högkontrastläge",
    "Enable dark high contrast mode" : "Aktivera mörkt högkontrastläge",
    "Similar to the high contrast mode, but with dark colours." : "Liknar högkontrastläget, men med mörka färger.",
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ett mörkt tema som underlättar för dina ögon genom att minska den totala ljusstyrkan.",
    "System default theme" : "Systemets standardtema",
    "Enable the system default" : "Aktivera systemets standard",
    "Using the default system appearance." : "Använder systemets standardutseende.",
    "Dyslexia font" : "Teckensnitt för dyslektiker",
    "Enable dyslexia font" : "Aktivera teckensnitt för dyslektiker",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt teckensnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Light theme" : "Ljust tema",
    "Enable the default light theme" : "Aktivera ljust standardtema",
    "The default light appearance." : "Standardutseende för ljust tema.",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Advanced options" : "Avancerade inställningar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen.",
    "Name" : "Namn",
    "Web link" : "Webblänk",
    "a safe home for all your data" : "ett säkert hem för all din data",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Background and login image" : "Bakgrund och inloggningsbild",
    "Upload new background and login image" : "Ladda upp ny bakgrund och inloggningsbild",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Ladda upp nya favicon",
    "User settings" : "Användarinställningar",
    "Disable user theming" : "Inaktivera teman för användare",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill genomdriva din anpassning kan du aktivera detta.",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Disable all keyboard shortcuts" : "Inaktivera alla tangentbordsgenvägar",
    "Background" : "Bakgrund",
    "Customization has been disabled by your administrator" : "Anpassning har inaktiverats av din administratör",
    "Set a custom background" : "Ställ in en anpassad bakgrund",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår problemhanterare{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt designteam{linkend}!",
    "Custom background" : "Anpassad bakgrund",
    "Default background" : "Standardbakgrund",
    "Change color" : "Ändra färg",
    "Remove background" : "Ta bort bakgrund",
    "Select a background from your files" : "Välj en bakgrund från dina filer",
    "Theme selection is enforced" : "Temaval är tvingande",
    "Select a custom color" : "Välj en anpassad färg",
    "Reset to default" : "Återställ till grundinställningar",
    "Upload" : "Ladda upp",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Loading preview…" : "Läser in förhandsvisning...",
    "Admin" : "Admin",
    "Error uploading the file" : "Det gick inte att ladda upp filen",
    "Name cannot be empty" : "Namn kan inte vara tom",
    "Open documentation" : "Öppna dokumentationen",
    "https://…" : "https://…",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen.",
    "Migrate and clean up admin theming images" : "Migrera och städa upp administratörens temabilder",
    "Failed to clean up the old admin theming images folder" : "Misslyckades att rensa den gamla admin tema-bildmappen",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Pick from Files" : "Välj från filer",
    "Default image" : "Standardbild",
    "Custom color" : "Anpassad färg",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill tvinga din anpassning kan du markera den här rutan."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig webbadress",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig webbadress",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig webbadress",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "Disable-user-theming should be true or false" : "Inaktivera teman för användare ska vara sant eller falskt",
    "Saved" : "Sparat",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "Dark theme with high contrast mode" : "Mörkt tema med högkontrastläge",
    "Enable dark high contrast mode" : "Aktivera mörkt högkontrastläge",
    "Similar to the high contrast mode, but with dark colours." : "Liknar högkontrastläget, men med mörka färger.",
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ett mörkt tema som underlättar för dina ögon genom att minska den totala ljusstyrkan.",
    "System default theme" : "Systemets standardtema",
    "Enable the system default" : "Aktivera systemets standard",
    "Using the default system appearance." : "Använder systemets standardutseende.",
    "Dyslexia font" : "Teckensnitt för dyslektiker",
    "Enable dyslexia font" : "Aktivera teckensnitt för dyslektiker",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt teckensnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Light theme" : "Ljust tema",
    "Enable the default light theme" : "Aktivera ljust standardtema",
    "The default light appearance." : "Standardutseende för ljust tema.",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Advanced options" : "Avancerade inställningar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen.",
    "Name" : "Namn",
    "Web link" : "Webblänk",
    "a safe home for all your data" : "ett säkert hem för all din data",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Background and login image" : "Bakgrund och inloggningsbild",
    "Upload new background and login image" : "Ladda upp ny bakgrund och inloggningsbild",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Ladda upp nya favicon",
    "User settings" : "Användarinställningar",
    "Disable user theming" : "Inaktivera teman för användare",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill genomdriva din anpassning kan du aktivera detta.",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Disable all keyboard shortcuts" : "Inaktivera alla tangentbordsgenvägar",
    "Background" : "Bakgrund",
    "Customization has been disabled by your administrator" : "Anpassning har inaktiverats av din administratör",
    "Set a custom background" : "Ställ in en anpassad bakgrund",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår problemhanterare{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt designteam{linkend}!",
    "Custom background" : "Anpassad bakgrund",
    "Default background" : "Standardbakgrund",
    "Change color" : "Ändra färg",
    "No background" : "Ingen bakgrund",
    "Select a background from your files" : "Välj en bakgrund från dina filer",
    "Theme selection is enforced" : "Temaval är tvingande",
    "Select a custom color" : "Välj en anpassad färg",
    "Reset to default" : "Återställ till grundinställningar",
    "Upload" : "Ladda upp",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Loading preview…" : "Läser in förhandsvisning...",
    "Admin" : "Admin",
    "Error uploading the file" : "Det gick inte att ladda upp filen",
    "Name cannot be empty" : "Namn kan inte vara tom",
    "Migrate and clean up admin theming images" : "Migrera och städa upp administratörens temabilder",
    "Failed to clean up the old admin theming images folder" : "Misslyckades att rensa den gamla admin tema-bildmappen",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Pick from Files" : "Välj från filer",
    "Default image" : "Standardbild",
    "Custom color" : "Anpassad färg",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}",
    "Open documentation" : "Öppna dokumentationen",
    "https://…" : "https://…",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill tvinga din anpassning kan du markera den här rutan.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen."
},
"nplurals=2; plural=(n != 1);");
